@@ -183,12 +183,17 @@ class AppsHttpDownloader:
         #id = node.getAttribute("id")
         #_logger.debug("parsing application id=%s", id)
         attrs = xml_get_attrs(node, ['id', 'rank', 'usageCount', 
-                                     'iconUrl', 
+                                     'iconUrl',
                                      'category',
                                      'name', 'desktopNames', 'packageNames',
                                      ('tooltip', True),
                                      ('genericName', True)
                                     ])
+        # If we leave rank and usageCount as strings, then in the
+        # future, cmp() will return bogus results
+        attrs['rank'] = int(attrs['rank'])
+        attrs['usageCount'] = int(attrs['usageCount'])
+        attrs['iconUrl'] = urlparse.urljoin(globals.get_baseurl(), attrs['iconUrl'])
         description = xml_query(node, 'description#')
         if description:
             attrs['description'] = description
@@ -227,7 +232,7 @@ class AppsHttpDownloader:
                                     child_nodes=reply_root.childNodes)
         self.__handler(apps)
 
-    def __on_error(self, url, args):
+    def __on_error(self, url, response):
         if response and 'status' in response and response['status'] == '504':
             _logger.debug("don't have local cache for %s", url)
         else:
